const {Continuum, ReportManagementStrategy, ModuleManagementStrategy} = require('@continuum/continuum-javascript-community');

describe('angularjs homepage', () => {
  beforeAll(async () => {
    await Continuum.setUp(browser, require('path').resolve(__dirname, "../support/continuum.conf.js"), null);
  });

  beforeEach(() => {
    // See https://github.com/angular/protractor/blob/master/docs/timeouts.md#waiting-for-angular-on-page-load
    // (uncomment for non-Angular applications)
    //browser.waitForAngularEnabled(false);

    browser.get('https://angularjs.org');

    // TODO: interact with the page using Protractor
    // e.g. type into text boxes, click on buttons, etc.
  });

  it('current page state should be free of accessibility concerns', async () => {
    const accessibilityConcerns = await Continuum.runAllTests(); // this takes an optional boolean argument that determines if the contents of an iframe will be scanned

    try {
      expect(accessibilityConcerns.length).toBe(0);
    } finally {
      console.log();
      console.log(`${accessibilityConcerns.length} accessibility concern(s) found:`);
      console.log(JSON.stringify(accessibilityConcerns, null, 2));

      // to send these accessibility concerns from Continuum to AMP, uncomment the line below and
      // edit the submitAccessibilityConcernsToAMP function according to our 'Sending Continuum Testing Results to AMP' support article:
      // https://support.levelaccess.com/hc/en-us/articles/360024510632-Sending-Continuum-Testing-Results-to-AMP
      //await submitAccessibilityConcernsToAMP(accessibilityConcerns);
	  // to send to the Level Access Platform, uncomment the line below
      // await submitAccessibilityConcernsToLevelAccessPlatform(accessibilityConcerns);
    }
  });
});

async function submitAccessibilityConcernsToAMP(accessibilityConcerns) {
  console.log();
  console.log("Submitting accessibility concerns to AMP...");

  const ampReportingService = Continuum.AMPReportingService;

  await ampReportingService.setActiveOrganization(12345);  // ID of AMP organization to submit test results to
  await ampReportingService.setActiveAsset(54321);  // ID of AMP asset to submit test results to
  await ampReportingService.setActiveReportByName("Example Report");
  await ampReportingService.setActiveModuleByName(await browser.getTitle(), await browser.getCurrentUrl());
  await ampReportingService.setActiveReportManagementStrategy(ReportManagementStrategy.OVERWRITE);
  await ampReportingService.setActiveModuleManagementStrategy(ModuleManagementStrategy.OVERWRITE);
  await ampReportingService.submitAccessibilityConcernsToAMP(accessibilityConcerns);

  console.log(`Accessibility concerns submitted to AMP: ${ampReportingService.activeModule.getAMPUrl()}`);
  console.log();
}

async function submitAccessibilityConcernsToLevelAccessPlatform(accessibilityConcerns) {
    try {
        const levelAccessPlatformReportingService = Continuum.LevelAccessPlatformReportingService;

        console.log("Submitting accessibility concerns to Level Access Platform...");
        await levelAccessPlatformReportingService.openScanSession({
            workspaceId: "63f4ded1311b17486d09ac28",
            digitalPropertyId: "63f4ded1311b17486d09ac2d",
            sessionName: "Example scan",
            scanTagId: "63effb372dde45a9b7530a94",
        });
        await levelAccessPlatformReportingService.submit(accessibilityConcerns);
        await levelAccessPlatformReportingService.completeScan();
        console.log(`Accessibility concerns submitted to Level Access Platform`);
    } catch (e) {
        console.log(e.message);
    }
}
